#
# spec file for package python-intake
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif

%{?sle15_python_module_pythons}
Name:           python-intake%{psuffix}
Version:        2.0.7
Release:        1.5
Summary:        Data loading and cataloging system
License:        BSD-2-Clause
URL:            https://github.com/intake/intake
Source:         https://github.com/intake/intake/archive/refs/tags/%{version}.tar.gz#/intake-%{version}-gh.tar.gz
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools >= 64}
BuildRequires:  %{python_module setuptools_scm >= 8}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-PyYAML
Requires:       python-fsspec >= 2023
Requires:       python-networkx
Requires:       python-platformdirs
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module intake = %{version}}
#
BuildRequires:  %{python_module Flask}
BuildRequires:  %{python_module Jinja2}
BuildRequires:  %{python_module aiohttp}
BuildRequires:  %{python_module dask-all}
BuildRequires:  %{python_module h5netcdf}
BuildRequires:  %{python_module hvplot}
# strictly a test req, but not a runtime requirement, not available in openSUSE
#BuildRequires:  %%{python_module intake-parquet}
BuildRequires:  %{python_module msgpack-numpy}
BuildRequires:  %{python_module notebook}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pandas}
BuildRequires:  %{python_module panel}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module xarray}
BuildRequires:  %{python_module zarr}
%endif
%python_subpackages

%description
A python package for describing, loading and processing data

Intake is an open-source package to:
 * describe your data declaratively
 * gather data sets into catalogs
 * search catalogs and services to find the right data you need
 * load, transform and output data in many formats
 * work with third party remote storage and compute platforms

%prep
%autosetup -p1 -n intake-%{version}

%build
%if !%{with test}
export SETUPTOOLS_SCM_PRETEND_VERSION=%{version}
%pyproject_wheel
%endif

%install
%if !%{with test}
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%if %{with test}
%check
# upstream currently only tests the readers subdir. The rest seems to still expect v1
# See .github/workflows/main.yaml
%pytest -rsfE intake/readers
%endif

%if !%{with test}
%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/intake
%{python_sitelib}/intake-%{version}.dist-info
%endif

%changelog
* Sun Oct  6 2024 Ben Greiner <code@bnavigator.de>
- Update to 2.0.7
  [#]# No upstream changelog. Providing some PR titles and commits:
  * cache system prompt file to disk
  * start llamacppservice on free port
  * supported short-form kwargs
  * double dash llama-server kwargs
  * Reimplement opendap auth for xarray reader
  * revise LlamaServerReader
  * Enable pattern URLs for xarray
* Fri Aug 30 2024 Ben Greiner <code@bnavigator.de>
- Unpin numpy 2 in testing
* Wed Aug 14 2024 Dirk Müller <dmueller@suse.com>
- switch to modern python for sle15
* Fri Jul 12 2024 Steve Kowalik <steven.kowalik@suse.com>
- Restrict numpy to < 2.
* Fri Mar 22 2024 Dirk Müller <dmueller@suse.com>
- update to 2.0.4:
  * readd entrypoints for old style sources
  * Fix "plugins" in old catalogs
* Wed Mar 13 2024 Matej Cepl <mcepl@cepl.eu>
- Don't try to build with Python 3.9
* Sun Mar 10 2024 Ben Greiner <code@bnavigator.de>
- Update to 2.0.3
  * Complete rewrite of the package
  * We are making Take2 as a full release. It is still “beta” in
    the sense that we will be adding many data types, readers and
    transformers, and are prepared to revisit the API in general.
    The reason not to use a pre-release or RC, is that users never
    see these.
  [#]# Relationship to V1
  * We aim to be largely backward compatible with pre-V2 Intake
    sources and catalogs. Many data sources have been rewritten to
    use the new framework, and many rarely-used features have been
    removed. In particular, the following features are no longer
    supported for V1 sources:
  - the intake server (use tiled instead)
  - caching (use fsspec caching instead or custom caching
    pipelines)
  - “persist” and “export” (use the new converters and output
    classes)
  - automatic hvplot (this is now an “output” converter for
    pandas and xarray types)
  - some niche source features such as CSV file pattern matching
  * In addition, not all existing intake_* packages have
    corresponding readers in Take2, but we are making progress.
- Drop fix-tests.patch
* Tue Jan 16 2024 Daniel Garcia <daniel.garcia@suse.com>
- Add fix-tests.patch to make the current version (0.7.0) compatible
  with latest version of panel, pandas and fsspec.
* Thu Jun  8 2023 Ben Greiner <code@bnavigator.de>
- Update to 0.7.0
  * be able to override arguments when using a source defined in an
    entry-point
  * make sources usable without explicit dependence on dask: zarr,
    textfiles, csv
  * removed some explicit usage (but not all) of dask throughout
    the codebase
  * new dataframe pipeline transform source
- Drop use-sys-executable.patch
* Wed Apr 12 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.6.8:
  * user parameter parsed as string before conversion to given type
  * numpy source becomes first to have read() path avoid dask
  * when registering drivers dynamically, corresponding open_* functions will
    be created automatically (plus refactor/cleanup of the discovery code)
  * catalog .gui attribute will make top-level GUI instance instead of cut
    down one-catalog version
  * server fix for upstream dask change giving newlined in report
  * editable plots, based on hvPlot's "explorer"
  * remove "text" input to YAMLFileCatalog
  * GUI bug fixes
  * allow catalog TTL as None
- Add patch use-sys-executable.patch:
  * Use sys.executable, rather than hardcoding python.
* Wed Nov 23 2022 Ben Greiner <code@bnavigator.de>
- Update to 0.6.6
  * Fixed bug in json and jsonl driver.
  * Ensure description is retained in the catalog.
  * Fix cache issue when running inside a notebook.
  * Add templating parameters.
  * Plotting api keeps hold of hvplot calls to allow other plots to
    be made.
  * docs updates
  * fix urljoin for server via proxy
- Remove manual entrypoint setup for test suite. It istaken care of
  by the %%pytest macro.
* Tue Apr 26 2022 Matej Cepl <mcepl@suse.com>
- Remove skip_python310, it is not needed anymore.
* Thu Feb  3 2022 Ben Greiner <code@bnavigator.de>
- Update to 0.6.5
  * no changelog
- Drop intake-pr601-dask-array.patch merged upstream
- Move to github archive because more tests were removed in the
  sdist
- Avoid tests with optional intake-parquet driver: New package
  would require significant effort including pyarrow
* Mon Jul 19 2021 Ben Greiner <code@bnavigator.de>
- Update to 0.6.2
  * no changelog
- Drop intake-pr560-fix-category-ordering.patch merged upstream
- Add intake-pr601-dask-array.patch for dask API change
  gh#intake/intake#601
* Sat Feb 13 2021 Ben Greiner <code@bnavigator.de>
- Update to 0.6.0
  * no changelog
- Skip python36 build: Packages depening on numpy are in the
  dependency tree (NEP 29)
- Add test files
  * tests-data.zarr.0
  * tests-data.zarr.zarray
  * calvert_uk_filter.tar.gz
- Add intake-pr560-fix-category-ordering.patch gh#intake/intake#560
  in order to support newer dask versions
* Mon May 25 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Thu Jan 30 2020 Todd R <toddrme2178@gmail.com>
- Update to 0.5.4
  * Allow for hvplot returning dynamic layouts
  * Make sure that ttl is numeric
  * add intake-nested-yaml-catalog plugin
  * check_meta_flag -> verify_meta
  * forgot to add pickle & json
  * fix dask version constraint
  * Don't replace "inteke" in remote server name
  * Update intake/gui/source/defined_plots.py
  * Use a generator for pagination.
  * add address to log
  * add server cli kwarg for address
  * dask.bytes to fsspec
  * don't check meta when merging dataframes
  * pin fsspec >= 0.3.6
  * return storage options if given
  * update open_file link
  * use the given encoder if not in the list
  * verify kwarg and dask version check
* Tue Nov 19 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.5.3
  * use frombuffer (fromstring is depr)
  * fix npy source
  * make example using storge_options usable
  * update docs around storage_options
  * Don't necessarily pass storage_options
  * fix with test
  * Add setup entrypoints for drivers and tidy CLI
  * Don't warn twice
  * Add drivers CLI test
  * update test
  * Add a load of tests
  * Fix msgpack imports so msgpack_numpy is not required.
  * ian-r-rose committed on Jul 26
  * Use master dask on pip build too
  * Don't import msgpack_numpy unless needed
  * prefer conda-forge for installs
  * Add constructor for tuples during safe load
  * Fixes on URLs
  * one remaining dask.bytes
  * Test basic passing on of filesystems
  * Pass filesystem stuff through
  * Merge branch 'master' into fs
  * Remove unused import.
  * Refine temp_config_path fixutre.
  * Improve test coverage of discovery.
  * Fix name error exposed by testing.
  * Fix log call missing msg arg.
  * Fix typo.
  * Issue PendingDeprecationWarning for do_package_scan.
  * Document that do_package_scan will be changed and then removed.
  * Remove __future__ imports.
  * wget syntax
  * much simpler travis script
  * simple build
  * deps
  * simplify travis installs
  * fix up
  * Merge branch 'master' into fs
  * replace dask.bytes imports
  * Fix typo --- intended length check.
  * Add autodiscover_all and list non-enabled plugins.
  * Add module docstring.
  * Look for and log entrypoint name collision.
  * Fix typo (local var name changed).
  * Document interaction between package scan and entrypoint.
  * Use 'raise from'.
  * Issue FutureWarning for any package_scan_results.
  * Fix typos.
  * Include module in debug log messages.
  * Fix typo
  * Fix shadowing.
  * Add debug logs. Separate discovery and loading.
  * Remove another unused import.
  * Roll back unneeded changes.
  * Update 'Making Drivers' docs.
  * Finish conf integration; update CLI.
  * Incorporate 'drivers' section in config.
  * Make test_which more robust.
  * Incorporate 'intake.drivers' entrypoint.
  * Make enable/disable accessible from Python API.
  * Remove Python 2 compat.
  * Skip unreadable entries after logging error.
  * Remove usage of six. Use yaml_load util func.
  * Fix biffed rebase.
  * Refine help string.
  * Add drivers.d system and drivers subcommand.
  * Minor typo fix in the "Making Drivers" docs
  * move the {en|de}code_datetime to the compat.{pack|unpack}_kwargs
  * Provide ndim attribute for npy accessor
  * added test to check if datetime user_parameters work
  * add use case for upload
  * handle lack of tz info
  * add tests for coerce_datetime and handle non-iterable input
  * fix numpy warning, and future issue with elementwise comparison
  * rm errant print()
  * added {en|de}code_datetime to various msgpack.{packb|unpackb}
  * Change API
  * WIP: is this the right add source API?
  * copy is_dataframe_like
  * add to API docs
  * Add uppload function and machinery
  * explicit reference to nested cats in conda packages
  * Update talks
  * Working FS
  * Update use_cases.rst
  * fixes
  * Merge branch 'master' into params_editor
  * revert line
  * mid
  * start
  * fix tests
  * Hide plot when changing source selection
  * inatke-examples link
  * rst not md
  * Update links to intake-examples and include GUI blog
  * Refactor to make one less copy.
  * Avoid accidental mutation.
  * Storage options applied to wrong FS in compressed cache
  * Add GUI classes
  * Merge branch 'master' into more_api
  * Add classes
  * Let GUI docs be visible; don't ever error on repr
* Mon Jun  3 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.5.1
  * Making sure that catalog and entry guis work
  * Making sure that logo is always part of panel
  * A little paranoia in case describe() exposes mutable state.
  * Do not nest inside 'source' key twice.
  * Work on copy that will be serialized.
  * Apply to info-get route
  * Don't attempt to serialise functions in server response
  * Defer inputs until needed
  * add intake-stac to plugins list
  * Allow local cat entry to specify explicit driver class
  * In GUI code, use describe() rather than attrbiutes
  * make msgpack_numpy optional
  * Don't pop plots from metadata
  * Don't remove plots from description
  * Add intake-dcat to the plugin directory.
  * Serializing and deserializing state
  * Add name to describe(), standardize describe() and describe_open()
  * Fixing up done_callback switch
  * Allow the expannding and collapsing of nested catalogs
  * Disable buttons when they aren't ready
- Fix jupyter dependencies.
* Mon Jan 21 2019 Todd R <toddrme2178@gmail.com>
- Initial version
